@@ -329,7 +329,7 @@ peas_plugin_loader_python_unload (PeasPluginLoader *loader,
   Py_XDECREF (pyinfo->module);
   pyg_gil_state_release (state);
 
-  pyinfo->module = NULL;
+  g_hash_table_remove (pyloader->priv->loaded_plugins, info);
 }
 
 static void
@@ -449,7 +449,12 @@ peas_python_init (PeasPluginLoaderPython *loader)
   if (prgname != NULL)
     argv[0] = prgname;
 
+#if PY_VERSION_HEX < 0x02060600
   PySys_SetArgv (1, argv);
+  PyRun_SimpleString ("import sys; sys.path.pop(0)\n");
+#else
+  PySys_SetArgvEx (1, argv, 0);
+#endif
 
   /* Note that we don't call this with the GIL held, since we haven't initialised pygobject yet */
   peas_plugin_loader_python_add_module_path (loader, PEAS_PYEXECDIR);
